package com.miaxis.app.controller.order;

import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.utils.SecurityUtils;
import com.miaxis.order.domain.OrderInfo;
import com.miaxis.order.dto.OrderInfoDto;
import com.miaxis.order.service.IOrderInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 【order】Controller
 *
 * @author miaxis
 * @date 2021-08-19
 */
@RestController
@RequestMapping(Constants.STUDENT_PREFIX+"/order/info")
@Api(tags={"【APP-订单接口】"})
public class OrderInfoController extends BaseController{
    @Autowired
    private IOrderInfoService orderInfoService;

    /**
     * 查询ad列表
     */
    @GetMapping("/list")
    @ApiOperation("查询订单列表")
        @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<OrderInfo> list(@ModelAttribute OrderInfoDto orderInfoDto){
        startPage();
        orderInfoDto.setReferralUserId(SecurityUtils.getLoginUser().getStudent().getId());
        List<OrderInfo> list = orderInfoService.selectOrderInfoList(orderInfoDto);
        return toResponsePageInfo(list);
    }

    /**
     *昨日预估收益
     */
    @GetMapping("/yesterdayTotal")
    @ApiOperation("昨日预估收益")
    public Response<Integer> yesterdayTotal(OrderInfoDto orderInfoDto) {
        orderInfoDto.setReferralUserId(SecurityUtils.getLoginUser().getStudent().getId());
        return Response.success(orderInfoService.selectYesterdayTotal(orderInfoDto));
    }


    /**
     *今日预估收益
     */
    @GetMapping("/todayTotal")
    @ApiOperation("今日预估收益")
    public Response<Integer> todayTotal(OrderInfoDto orderInfoDto) {
        orderInfoDto.setReferralUserId(SecurityUtils.getLoginUser().getStudent().getId());
        return Response.success(orderInfoService.selectTodayTotal(orderInfoDto));
    }


    /**
     * 总收益
     */
    @GetMapping("/total")
    @ApiOperation("总收益")
    public Response<Integer> total(OrderInfoDto orderInfoDto) {
        orderInfoDto.setReferralUserId(SecurityUtils.getLoginUser().getStudent().getId());
        return Response.success(orderInfoService.selectTotal(orderInfoDto));
    }

}
